﻿Imports Brainboxes.IO

Module VBConsoleModule

    Sub Main()
        Dim ed As EDDevice = Nothing
        Try
            'tcp connection
            Dim connection As IConnection = New TCPConnection("192.168.0.158")
            'or serial connection on COM3
            'connection = new SerialConnection(3)

            'ED588 is the model number of the device could be e.g. ED038, ED204 etc.
            ed = New ED588(connection)
            ed.Label = "Pump Control in Cabinet 3" 'optionally assign a label, useful for debugging

            'open connection
            ed.Connect()

            'set all outputs open/off/0
            ed.Outputs.Values = 0

            'set Dout0 closed/on/1
            ed.Outputs(0).Value = 1

            'optionally label a line for ease when debugging
            ed.Inputs(3).Label = "Pump enabled Monitor"

            'add event handler for rising edge on Din3
            AddHandler ed.Inputs(3).IOLineRisingEdge, AddressOf DIN3IOLineRisingEdge

            'add event handler for falling edge on any of the inputs
            AddHandler ed.Inputs.IOLineFallingEdge, AddressOf Inputs_IOLineFallingEdge

            'add event handler for any change on any of the inputs or outputs of the device
            AddHandler ed.IOLineChanged, AddressOf ed_IOLineChanged

            Console.WriteLine("Press enter to exit...")
            Console.ReadKey()

        Catch ex As Exception
            Console.WriteLine("Exception Occurred")
            Console.WriteLine(ex)
            Console.WriteLine("Press enter to exit...")
            Console.ReadKey()
        Finally
            'close connections after a key press
            If ed IsNot Nothing Then
                ed.Disconnect()
            End If
        End Try
    End Sub


    'called when DIN3 goes from 0 -> 1
    Public Sub DIN3IOLineRisingEdge(line As IOLine, device As EDDevice, changeType As IOChangeTypes)
        Console.WriteLine(line.ToString() & " rising edge!")
        'or for full debug data about line:
        Console.WriteLine(line.Describe())
    End Sub

    'called when any of the inputs goes from 1 -> 0
    Public Sub Inputs_IOLineFallingEdge(line As IOLine, device As EDDevice, changeType As IOChangeTypes)
        Console.WriteLine(line.ToString() & " falling edge!")
    End Sub

    'called when any change occurs on any of the inputs or output
    Public Sub ed_IOLineChanged(line As IOLine, device As EDDevice, changeType As IOChangeTypes)
        Console.WriteLine(line.ToString() & " of device " & device.ToString())

        'changeType can be one of:
        ' IOChangeTypes.FallingEdge
        ' IOChangeTypes.RisingEdge
        ' IOChangeTypes.Latched -- within the sample time the line has transitioned 2 times

        'or for full debug data about device:
        Console.WriteLine(device.Describe())
    End Sub

End Module
